Information Retrieval
============

Video Lectures
============

[<img src=https://github.com/StarlangSoftware/InformationRetrieval/blob/master/video1.jpg width="50%">](https://youtu.be/DhjZPVrvdnE)[<img src=https://github.com/StarlangSoftware/InformationRetrieval/blob/master/video2.jpg width="50%">](https://youtu.be/rfNoyFw-_g8)[<img src=https://github.com/StarlangSoftware/InformationRetrieval/blob/master/video3.jpg width="50%">](https://youtu.be/sYHVpTZL6o4)[<img src=https://github.com/StarlangSoftware/InformationRetrieval/blob/master/video4.jpg width="50%">](https://youtu.be/bRckCK9VcKQ)[<img src=https://github.com/StarlangSoftware/InformationRetrieval/blob/master/video5.jpg width="50%">](https://youtu.be/ZX4zTT69ll0)[<img src=https://github.com/StarlangSoftware/InformationRetrieval/blob/master/video6.jpg width="50%">](https://youtu.be/AVoLka-LDXY)[<img src=https://github.com/StarlangSoftware/InformationRetrieval/blob/master/video7.jpg width="50%">](https://youtu.be/5GOyBTeSJwo)[<img src=https://github.com/StarlangSoftware/InformationRetrieval/blob/master/video8.jpg width="50%">](https://youtu.be/-iu6N8KZslw)[<img src=https://github.com/StarlangSoftware/InformationRetrieval/blob/master/video9.jpg width="50%">](https://youtu.be/LwQYHFyDd8U)[<img src=https://github.com/StarlangSoftware/InformationRetrieval/blob/master/video10.jpg width="50%">](https://youtu.be/Y_jS03r6GMI)[<img src=https://github.com/StarlangSoftware/InformationRetrieval/blob/master/video11.jpg width="50%">](https://youtu.be/msRT2yx0yms)[<img src=https://github.com/StarlangSoftware/InformationRetrieval/blob/master/video12.jpg width="50%">](https://youtu.be/B5RProYhMvk)[<img src=https://github.com/StarlangSoftware/InformationRetrieval/blob/master/video13.jpg width="50%">](https://youtu.be/dxc3ONoW63E)

For Developers
============

You can also see [Java](https://github.com/starlangsoftware/InformationRetrieval), [Cython](https://github.com/starlangsoftware/InformationRetrieval-Cy), [C++](https://github.com/starlangsoftware/InformationRetrieval-CPP), [Js](https://github.com/starlangsoftware/InformationRetrieval-Js), or [C#](https://github.com/starlangsoftware/InformationRetrieval-CS) repository.
